@@ -3,7 +3,7 @@ use on_drop::OnDrop;
 
 #[test]
 fn test() {
-    let list = LinkedList::new();
+    let mut list = LinkedList::new();
 
     let (item, token) = OnDrop::token(1);
     let mut node1 = Node::new_with(item);
